#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-2k4DcPEIAWn820K2shevEi
key:                  skylighting-format-ansi-0.1-2k4DcPEIAWn820K2shevEi
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  3f45952fe2d09d51bc002ce8552d621a
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.6.6/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/skylighting-format-ansi-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-2k4DcPEIAWn820K2shevEi
depends:
    ansi-terminal-1.1-FMAjddYCnoo35p0Ajg6Jk8 base-4.18.2.1
    binary-0.8.9.1 colour-2.3.7-52DaKKnDbdRf7CUEo3dC5 containers-0.6.7
    skylighting-core-0.14.5-2yBC1VcUmQ0Js1tSxtTOlD text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

